BEGIN {
    Name        = "Translate Shell"
    Description = "Google Translate to serve as a command-line tool"
    Version     = "0.9.2.1"
    ReleaseDate = "2015-12-18"
    Command     = "trans"
    EntryPoint  = "translate.awk"
}
